@@ -800,8 +800,53 @@ instead of the default `denote-sequence-annotate-types'."
      (completing-read
       (format-prompt (or prompt-text "Select sequence type") default)
       (denote-get-completion-table (or types denote-sequence-types) '(category . denote-sequence-type))
-      nil :require-match nil
-      'denote-sequence-type-history default))))
+      nil t nil 'denote-sequence-type-history default))))
+
+(defun denote-sequence-file-prompt-affixate (files)
+  "Affixate FILES.
+Use the identifier as a prefix, the keywords as a suffix, and the title
+as the text of the candidate.
+
+Include in the text of the candidate the file extesion.  A group
+function can remove it, such as with `denote-file-prompt-group'."
+  (mapcar
+   (lambda (file)
+     (let ((sequence (denote-retrieve-filename-signature file)))
+       (list
+        file
+        (format "%s " (propertize sequence 'face 'completions-annotations))
+        (format " %s%s"
+                (if (eq completions-format 'one-column)
+                    (propertize " " 'display '(space :align-to 90))
+                  " ")
+                (propertize (or (denote-retrieve-filename-keywords file) "") 'face 'completions-annotations)))))
+   files))
+
+(defun denote-sequence-file-prompt-group (file transform)
+  "Retun group of FILE if TRANSFORM is non-nil, per `completion-metadata'."
+  (cond
+   (transform
+    (denote-retrieve-filename-title file))
+   ((string-match-p (regexp-opt denote-encryption-file-extensions) file)
+    "Encrypted")
+   ((string-match-p (regexp-opt (denote-file-type-extensions)) file)
+    "Notes")
+   ((string-match-p "\\.\\(pdf\\|epub\\)" file)
+    "Documents")
+   (t "Other files")))
+
+(defvar denote-sequence-file-prompt-extra-metadata
+  (list
+   ;; NOTE 2025-12-15: If we use the `file' category, then we are
+   ;; subject to the `completion-category-overrides'.  This is a
+   ;; problem because the user will want to, for example, sort
+   ;; directories before files, but then we cannot have our sort here.
+   (cons 'category 'file)
+   (cons 'group-function #'denote-sequence-file-prompt-group)
+   (cons 'affixation-function #'denote-sequence-file-prompt-affixate)
+   (cons 'display-sort-function #'denote-sequence-sort-files))
+  "Extra `completion-metadata' for the `denote-file-prompt'.
+This is in addition to the completion category, which is constant.")
 
 (defvar denote-sequence-file-history nil
   "Minibuffer history for `denote-sequence-file-prompt'.")
@@ -814,16 +859,26 @@ With optional PROMPT-TEXT use it instead of a generic prompt.
 
 With optional FILES-WITH-SEQUENCES as a list of strings, use them as
 completion candidates.  Else use `denote-sequence-get-all-files'."
-  (if-let* ((relative-files (mapcar #'denote-get-file-name-relative-to-denote-directory
-                                    (or files-with-sequences (denote-sequence-get-all-files))))
-            (prompt (format-prompt (or prompt-text "Select FILE with sequence") nil))
-            (input (completing-read
-                    prompt
-                    (denote-get-completion-table relative-files '(category . file))
-                    nil :require-match
-                    nil 'denote-sequence-file-history)))
-      (expand-file-name input (car (denote-directories)))
-    (error "There are no sequence notes in the `denote-directory'")))
+  (let* ((roots (denote-directories))
+         (single-dir-p (null (cdr roots)))
+         ;; Some external program may use `default-directory' with the
+         ;; relative file paths of the completion candidates.
+         (default-directory (if single-dir-p
+                                (car roots)
+                              (denote-directories-get-common-root roots))))
+    (if-let* ((files (or files-with-sequences (denote-sequence-get-all-files)))
+              (relative-files (if single-dir-p
+                                  (mapcar #'denote-get-file-name-relative-to-denote-directory files)
+                                files))
+              (prompt (format-prompt (or prompt-text "Select FILE with sequence") nil))
+              (input (completing-read
+                      prompt
+                      (apply 'denote-get-completion-table relative-files denote-sequence-file-prompt-extra-metadata)
+                      nil t nil 'denote-sequence-file-history)))
+        (if single-dir-p
+            (expand-file-name input default-directory)
+          input)
+      (error "There are no sequence notes in the `denote-directory'"))))
 
 ;;;###autoload
 (defun denote-sequence (type &optional file-with-sequence)
@@ -1052,7 +1107,7 @@ is ignored."
   (completing-read
    (format-prompt (or prompt-text "Select an existing sequence (empty for all)") nil)
    (or sequences (denote-sequence-get-all-sequences))
-   #'denote-sequence-p :require-match nil 'denote-sequence-history))
+   #'denote-sequence-p t nil 'denote-sequence-history))
 
 (defvar denote-sequence-depth-history nil
   "Minibuffer history of `denote-sequence-depth-prompt'.")
@@ -1115,7 +1170,7 @@ is that many levels deep.  For example, 1=1=2 is three levels deep.
 For a more specialised case, see `denote-sequence-find-relatives-dired'."
   (interactive (denote-sequence--get-interactive-for-prefix-and-depth))
   (let* ((roots (denote-directories))
-         (relative-p (null (cdr roots)))
+         (single-dir-p (null (cdr roots)))
          (files-fn (lambda ()
                      (let* ((files (if (and prefix (not (string-blank-p prefix)))
                                        (denote-sequence-get-all-files-with-prefix prefix)
@@ -1124,11 +1179,11 @@ For a more specialised case, see `denote-sequence-find-relatives-dired'."
                                                   (denote-sequence-get-all-files-with-max-depth depth files)
                                                 files))
                             (files-sorted (denote-sequence-sort-files files-with-depth)))
-                       (if relative-p
+                       (if single-dir-p
                            (mapcar #'file-relative-name files-sorted)
                          files-sorted)))))
-    (if-let* ((directory (if relative-p ; see comment in `denote-file-prompt'
-                             (car (denote-directories))
+    (if-let* ((directory (if single-dir-p
+                             (car roots)
                            (denote-directories-get-common-root roots)))
               (files (funcall files-fn))
               (dired-name (denote-format-buffer-name
